@@ -41,13 +41,13 @@
 #' sapply(out, NROW)
 #' }
 leda <- function(trait = "age_first_flowering", ...) {
-  tt <- GET(URLencode(paste0(leda_base(), pick_file_name(trait))), ...)
+  tt <- GET(utils::URLencode(paste0(leda_base(), pick_file_name(trait))), ...)
   out <- rawToChar(content(tt, "raw", encoding = "UTF-8"))
   stop_for_status(tt)
   out <- iconv(out, "latin1", "UTF-8")
   str <- sub("^\\r\\n\\r\\n", "", substring(out, regexpr("\r\n\r", out)[1], nchar(out)))
   df <- suppressWarnings(readr::read_delim(str, delim = ";"))
-  setNames(df, gsub("\\s", "_", tolower(names(df))))
+  stats::setNames(df, gsub("\\s", "_", tolower(names(df))))
 }
 
 pick_file_name <- function(x) {
