@@ -4,23 +4,24 @@
 #' @template ncbi
 #' @param id (\code{character}) Taxonomic id to search for. Not compatible with
 #'    argument \code{taxa}.
-#' @param limit (\code{numeric}) Number of sequences to search for and return. Max of 10,000.
-#'    If you search for 6000 records, and only 5000 are found, you will of course
-#'    only get 5000 back.
-#' @param entrez_query (\code{character}; length 1) An Entrez-format query to filter results with.
-#'   This is useful to search for sequences with specific characteristics. The format is the same
-#'   as the one used to seach genbank.
-#'   (\url{https://www.ncbi.nlm.nih.gov/books/NBK3837/#EntrezHelp.Entrez_Searching_Options})
-#' @param fuzzy (logical) Whether to do fuzzy taxonomic ID search or exact search. If \code{TRUE},
-#'    we use \code{xXarbitraryXx[porgn:__txid<ID>]}, but if \code{FALSE}, we use \code{txid<ID>}.
-#'    Default: \code{FALSE}
-#' @param hypothetical (\code{logical}; length 1) If \code{FALSE}, an attempt will be made to not
-#'   return hypothetical or predicted sequences judging from accession number prefixs (XM and XR).
-#'   This can result in less than the \code{limit} being returned even if there are more sequences
-#'   available, since this filtering is done after searching NCBI.
+#' @param limit (\code{numeric}) Number of sequences to search for and return.
+#' Max of 10,000. If you search for 6000 records, and only 5000 are found,
+#' you will of course only get 5000 back.
+#' @param entrez_query (\code{character}; length 1) An Entrez-format query to
+#' filter results with. This is useful to search for sequences with specific
+#' characteristics. The format is the same as the one used to seach genbank.
+#' (\url{https://www.ncbi.nlm.nih.gov/books/NBK3837/#EntrezHelp.Entrez_Searching_Options})
+#' @param fuzzy (logical) Whether to do fuzzy taxonomic ID search or exact
+#' search. If \code{TRUE}, we use \code{xXarbitraryXx[porgn:__txid<ID>]},
+#' but if \code{FALSE}, we use \code{txid<ID>}. Default: \code{FALSE}
+#' @param hypothetical (\code{logical}; length 1) If \code{FALSE}, an attempt
+#' will be made to not return hypothetical or predicted sequences judging from
+#' accession number prefixs (XM and XR). This can result in less than the
+#' \code{limit} being returned even if there are more sequences available,
+#' since this filtering is done after searching NCBI.
 #' @return \code{data.frame} of results if a single input is given. A list of
 #'  \code{data.frame}s if multiple inputs are given.
-#' @seealso \code{\link[taxize]{ncbi_getbyid}}, \code{\link[taxize]{ncbi_getbyname}}
+#' @seealso \code{\link{ncbi_byid}}, \code{\link{ncbi_byname}}
 #' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}, Zachary Foster
 #'   \email{zacharyfoster1989@@gmail.com}
 #' @examples \dontrun{
@@ -31,7 +32,8 @@
 #' # If the taxon name is unique, using the taxon name and id are equivalent
 #' all(ncbi_searcher(id = "75935") ==  ncbi_searcher(taxa="Umbra limi"))
 #' # If the taxon name is not unique, use taxon id
-#' #  "266948" is the uid for the butterfly genus, but there is also a genus of orchids with the
+#' #  "266948" is the uid for the butterfly genus, but there is also a genus
+#' #  of orchids with the
 #' #  same name
 #' nrow(ncbi_searcher(id = "266948")) ==  nrow(ncbi_searcher(taxa="Satyrium"))
 #' # get list of genes available, removing non-unique
@@ -40,7 +42,8 @@
 #' out[grep("RAG1", out$gene_desc, ignore.case=TRUE),]
 #'
 #' # A single species without records in NCBI
-#' out <- ncbi_searcher(taxa="Sequoia wellingtonia", seqrange="1:2000", getrelated=TRUE)
+#' out <- ncbi_searcher(taxa="Sequoia wellingtonia", seqrange="1:2000",
+#'   getrelated=TRUE)
 #'
 #' # Many species, can run in parallel or not using plyr
 #' species <- c("Salvelinus alpinus","Ictalurus nebulosus","Carassius auratus")
@@ -56,11 +59,13 @@
 #'             entrez_query = "18S[title] AND 28S[title]")
 #'
 #' # get refseqs
-#' one <- ncbi_searcher(taxa = "Salmonella enterica", entrez_query="srcdb_refseq[PROP]")
+#' one <- ncbi_searcher(taxa = "Salmonella enterica",
+#'   entrez_query="srcdb_refseq[PROP]")
 #' two <- ncbi_searcher(taxa = "Salmonella enterica")
 #' }
-ncbi_searcher <- function(taxa = NULL, id = NULL, seqrange="1:3000", getrelated=FALSE, fuzzy=FALSE,
-                          limit = 500, entrez_query = NULL, hypothetical = FALSE, verbose=TRUE) {
+ncbi_searcher <- function(taxa = NULL, id = NULL, seqrange="1:3000",
+  getrelated=FALSE, fuzzy=FALSE, limit = 500, entrez_query = NULL,
+  hypothetical = FALSE, verbose=TRUE) {
 
   # Argument validation ----------------------------------------------------------------------------
   if (sum(c(is.null(taxa), is.null(id))) != 1) {
@@ -224,7 +229,11 @@ taxonomy <- function(zz) {
     out[[ uids[i] ]] <- xml2::xml_text(xml2::xml_find_all(xml, '//Item[@Name="ScientificName"]'))
   }
   for (i in seq_along(out)) {
-    taxids[grepl(names(out)[i], taxids)] <- out[[i]]
+    if (length(out[[i]]) == 0) {
+      taxids[grepl(names(out)[i], taxids)] <- NA_character_
+    } else {
+      taxids[grepl(names(out)[i], taxids)] <- out[[i]]
+    }
   }
   return(taxids)
 }
